BaseRegExpRecipe class final

Inheritance

Constructors

BaseRegExpRecipe(String expr, {RegExpTag tag = RegExpTag.none})

Properties

expr String
final
hasCompiled bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources List<RegExpRecipe>
finalinherited
tag RegExpTag
finalinherited
withCapturesIgnored TrackedRegExpRecipe
A special "uncaptured" version of this recipe that ignores all captures within it
latefinalinherited

Methods

compile() String
inherited
copy({String? expr, RegExpTag? tag}) BaseRegExpRecipe
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionOf(GroupRef ref) int
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited