GroupTracker class final

Constructors

GroupTracker()
const

Properties

groupCount int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPosition(GroupRef ref) int
increment([int by = 1]) GroupTracker
markAllIgnored() GroupTracker
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTracking(GroupRef newRef, [int position = 1]) GroupTracker
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

combine(Iterable<GroupTracker> trackers) GroupTracker