RegExpRecipe class sealed

Implementers

Properties

hasCompiled bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources List<RegExpRecipe>
final
tag RegExpTag
final
withCapturesIgnored TrackedRegExpRecipe
A special "uncaptured" version of this recipe that ignores all captures within it
latefinal

Methods

compile() String
copy({RegExpTag? tag}) RegExpRecipe
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionOf(GroupRef ref) int
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited