RegExpPair class final

Constructors

RegExpPair(RegExpRecipe begin, RegExpRecipe end)

Properties

begin RegExpRecipe
final
end RegExpRecipe
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asSingleRecipe([RegExpRecipe? between]) RegExpRecipe
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited