SyntaxDefinition<BuilderT extends RegExpBuilder<CollectionT>, CollectionT> class abstract base

Constructors

SyntaxDefinition({String? scopePrefix, required bool isTextSyntax, required String langName, required List<String> fileTypes, required BuilderT builder})

Properties

collection ↔ CollectionT
latefinal
entireRecipe GroupRef
latefinal
fileTypes List<String>
final
hashCode int
The hash code for this object.
no setterinherited
isTextSyntax bool
final
langName String
final
mainBody MainBody
latefinal
rootUnits List<ScopeUnit>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopePrefix String?
final
self ScopeUnit
latefinal

Methods

createUnit(String identifier, {StyleName? styleName, RegExpRecipe? match, RegExpPair? matchPair, Map<GroupRef, StyleName>? captures, Map<GroupRef, StyleName>? beginCaptures, Map<GroupRef, StyleName>? endCaptures, List<ScopeUnit>? innerUnits()?}) ScopeUnit
createUnitInline({StyleName? styleName, RegExpRecipe? match, RegExpPair? matchPair, Map<GroupRef, StyleName>? captures, Map<GroupRef, StyleName>? beginCaptures, Map<GroupRef, StyleName>? endCaptures, List<ScopeUnit>? innerUnits()?}) ScopeUnit
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited