EnclosurePattern class final
- Inheritance
-
- Object
- SyntaxElement
- Pattern
- GroupingPattern
- EnclosurePattern
Constructors
-
EnclosurePattern({required String debugName, StyleName? styleName, List<
Pattern> innerPatterns = const [], required String begin, required String end, Map<int, CapturePattern> beginCaptures = const {}, Map<int, CapturePattern> endCaptures = const {}}) -
const
Properties
- begin → String
-
final
-
beginCaptures
→ Map<
int, CapturePattern> -
final
- debugName → String
-
finalinherited
- end → String
-
final
-
endCaptures
→ Map<
int, CapturePattern> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
innerPatterns
→ List<
Pattern> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleName → StyleName?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
Converts
thisand returns a Map representing a JSON object. This allows for easy integration with dart's JsonEncoder class.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited