IncludePattern class final
- Inheritance
-
- Object
- SyntaxElement
- Pattern
- IncludePattern
Constructors
- IncludePattern({required String identifier, String debugName = "", bool isRepoItemRef = true})
-
const
Properties
- debugName → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleName → StyleName?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
Converts
thisand returns a Map representing a JSON object. This allows for easy integration with dart's JsonEncoder class.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited