SyntaxElement class sealed
The base class for various kinds of TextMate JSON elements.
Each subtype of this is intended to be a data class/map for a separate kind of TextMate element. (See each class' docstring for an example of what it represents.) It is the responsibility of these subtypes to implement toJson and define all properties needed to create the corresponding JSON representaton. Some classes may also define conversion methods to other element types.
Subclasses of this must have toJson implemented, as guaranteed by the
JsonEncodable interface. This method is responsible for returning the actual
JSON representation of this element.
- Implemented types
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
Converts
thisand returns a Map representing a JSON object. This allows for easy integration with dart's JsonEncoder class.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited