instance property
The singleton instance to use to access all printing methods.
Implementation
static final instance = SyntaxPrinter._create();
The singleton instance to use to access all printing methods.
static final instance = SyntaxPrinter._create();