print method

String print(
  1. SyntaxElement element
)

"Prints" a given element by converting it to a string containing its JSON representation. Each SyntaxElement represents a kind of JSON object, so passing any type of element is acceptable.

Implementation

String print(SyntaxElement element) {
  return _encoder.convert(element) + "\n";
}