Constructors
Properties
- anything → RegExpRecipe
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- nothing → RegExpRecipe
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aheadIs(
RegExpRecipe inner) → RegExpRecipe -
aheadIsNot(
RegExpRecipe inner) → RegExpRecipe -
behindIs(
RegExpRecipe inner) → RegExpRecipe -
behindIsNot(
RegExpRecipe inner) → RegExpRecipe -
capture(
RegExpRecipe inner, [GroupRef? ref]) → RegExpRecipe -
chars(
String charSet) → RegExpRecipe -
concat(
List< RegExpRecipe> recipes, {bool allowDuplicateRefs = false}) → RegExpRecipe -
createCollection(
) → CollectionT -
either(
List< RegExpRecipe> branches, {bool allowDuplicateRefs = false}) → RegExpRecipe -
endsWith(
RegExpRecipe inner) → RegExpRecipe -
exactly(
String string) → RegExpRecipe -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notChars(
String charSet) → RegExpRecipe -
oneOrMore(
RegExpRecipe inner) → RegExpRecipe -
optional(
RegExpRecipe inner) → RegExpRecipe -
pair(
{required RegExpRecipe begin, required RegExpRecipe end}) → RegExpPair -
phrase(
String string) → RegExpRecipe -
repeatAtLeast(
int times, RegExpRecipe inner) → RegExpRecipe -
repeatAtMost(
int times, RegExpRecipe inner) → RegExpRecipe -
repeatBetween(
RegExpRecipe inner, int lowTimes, int highTimes) → RegExpRecipe -
repeatEqual(
int times, RegExpRecipe inner) → RegExpRecipe -
space(
{required bool req}) → RegExpRecipe -
spaceAfter(
RegExpRecipe inner) → RegExpRecipe -
spaceAround(
RegExpRecipe inner) → RegExpRecipe -
spaceAroundReqAfter(
RegExpRecipe inner) → RegExpRecipe -
spaceAroundReqBefore(
RegExpRecipe inner) → RegExpRecipe -
spaceBefore(
RegExpRecipe inner) → RegExpRecipe -
spaceReqAfter(
RegExpRecipe inner) → RegExpRecipe -
spaceReqAround(
RegExpRecipe inner) → RegExpRecipe -
spaceReqBefore(
RegExpRecipe inner) → RegExpRecipe -
startsAndEndsWith(
RegExpRecipe inner) → RegExpRecipe -
startsWith(
RegExpRecipe inner) → RegExpRecipe -
toString(
) → String -
A string representation of this object.
inherited
-
zeroOrMore(
RegExpRecipe inner) → RegExpRecipe
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited