ScopeUnit class final
Properties
-
baseSyntax
→ SyntaxDefinition<
RegExpBuilder, dynamic> -
final
-
createBody
→ Pattern Function(String debugName, List<
Pattern> innerPatterns) -
final
-
createInnerUnits
→ List<
ScopeUnit> ? Function()? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
-
innerUnits
→ List<
ScopeUnit> -
latefinal
- isInline → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asInnerPattern(
) → Pattern -
asRepositoryItem(
) → RepositoryItem -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited