MainBody class final
Represents an entire TextMate object contained in a language file. This includes the supported file types, the language scope name, root patterns, and the named repository patterns.
{
"fileTypes": [
"txt",
"dart",
// etc
],
"scopeName": "language.scope.name",
"patterns": [
// <Pattern>,
// ...
],
"repository": {
// <RepositoryItem>,
// ...
}
}
- Inheritance
-
- Object
- SyntaxElement
- MainBody
Constructors
Properties
-
fileTypes
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTextSyntax → bool
-
final
- langName → String
-
final
-
repository
→ List<
RepositoryItem> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopePrefix → String?
-
final
-
topLevelPatterns
→ List<
Pattern> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
Converts
thisand returns a Map representing a JSON object. This allows for easy integration with dart's JsonEncoder class.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited