vscode_theming_tools library
Classes
- CapturePattern
- EnclosurePattern
- GroupingPattern
- GroupRef
- IncludePattern
- JsonEncodable
- Guarantees that an implementor can work properly with the JSON encoding process.
- MainBody
- Represents an entire TextMate object contained in a language file. This includes the supported file types, the language scope name, root patterns, and the named repository patterns.
- MatchPattern
- Pattern
-
RegExpBuilder<
CollectionT> - RegExpPair
- RegExpRecipe
- RepositoryItem
- ScopeUnit
- StyleName
-
SyntaxDefinition<
BuilderT extends RegExpBuilder< CollectionT> , CollectionT> - SyntaxElement
- The base class for various kinds of TextMate JSON elements.
- SyntaxPrinter
- Converts a SyntaxElement into its JSON string representation.
Properties
- regExpBuilder → _BlankBuilder
-
final